"""
Training functions
"""

import torch


def get_device(use_mps=True):
    """Return the available GPU/CPU device"""

    if torch.cuda.is_available():
        device = torch.device("cuda")
        message = f"Using CUDA GPU {torch.cuda.get_device_name(0)} :)"
    elif use_mps and torch.backends.mps.is_available():
        device = torch.device("mps")
        message = "Using MPS GPU :)"
    else:
        device = torch.device("cpu")
        message = "No GPU found, using CPU instead"

    return device, message



"""
Plotting functions
"""

import matplotlib.pyplot as plt


def plot_loss_acc(history):
    """Plot training loss and accuracy. Takes a Keras-like History object as parameter"""

    loss_values = history["loss"]
    recorded_epochs = range(1, len(loss_values) + 1)

    fig, (ax1, ax2) = plt.subplots(2, 1)
    ax1.plot(recorded_epochs, loss_values, ".--", label="Training loss")
    ax1.set_ylabel("Loss")
    ax1.legend()

    acc_values = history["acc"]
    ax2.plot(recorded_epochs, acc_values, ".--", label="Training accuracy")
    ax2.set_xlabel("Epochs")
    ax2.set_ylabel("Accuracy")
    plt.legend()

    final_loss = loss_values[-1]
    final_acc = acc_values[-1]
    fig.suptitle(
        f"Training loss: {final_loss:.5f}. Training accuracy: {final_acc*100:.2f}%"
    )
    plt.show()
